Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(368)

Unified Diff: content/public/common/common_param_traits.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/origin_util.cc ('k') | content/renderer/pepper/pepper_platform_audio_output_dev.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/common_param_traits.cc
diff --git a/content/public/common/common_param_traits.cc b/content/public/common/common_param_traits.cc
index 2a990c4c3119f0b722962802d60189106ef7c496..0c57769fd975efcc1e75bbd8eb349bbc59c7737d 100644
--- a/content/public/common/common_param_traits.cc
+++ b/content/public/common/common_param_traits.cc
@@ -18,7 +18,7 @@ namespace IPC {
void ParamTraits<url::Origin>::GetSize(base::PickleSizer* s,
const param_type& p) {
- GetParamSize(s, p.unique());
+ GetParamSize(s, p.opaque());
GetParamSize(s, p.scheme());
GetParamSize(s, p.host());
GetParamSize(s, p.port());
@@ -26,7 +26,7 @@ void ParamTraits<url::Origin>::GetSize(base::PickleSizer* s,
}
void ParamTraits<url::Origin>::Write(base::Pickle* m, const url::Origin& p) {
- WriteParam(m, p.unique());
+ WriteParam(m, p.opaque());
WriteParam(m, p.scheme());
WriteParam(m, p.host());
WriteParam(m, p.port());
@@ -36,26 +36,26 @@ void ParamTraits<url::Origin>::Write(base::Pickle* m, const url::Origin& p) {
bool ParamTraits<url::Origin>::Read(const base::Pickle* m,
base::PickleIterator* iter,
url::Origin* p) {
- bool unique;
+ bool opaque;
std::string scheme;
std::string host;
uint16_t port;
std::string suborigin;
- if (!ReadParam(m, iter, &unique) || !ReadParam(m, iter, &scheme) ||
+ if (!ReadParam(m, iter, &opaque) || !ReadParam(m, iter, &scheme) ||
!ReadParam(m, iter, &host) || !ReadParam(m, iter, &port) ||
!ReadParam(m, iter, &suborigin)) {
*p = url::Origin();
return false;
}
- *p = unique ? url::Origin()
+ *p = opaque ? url::Origin()
: url::Origin::UnsafelyCreateOriginWithoutNormalization(
scheme, host, port, suborigin);
// If a unique origin was created, but the unique flag wasn't set, then
// the values provided to 'UnsafelyCreateOriginWithoutNormalization' were
// invalid; kill the renderer.
- if (!unique && p->unique())
+ if (!opaque && p->opaque())
return false;
return true;
« no previous file with comments | « content/common/origin_util.cc ('k') | content/renderer/pepper/pepper_platform_audio_output_dev.cc » ('j') | no next file with comments »
@@ -36,26 +36,26 @@ void ParamTraits<url::Origin>::Write(base::Pickle* m, const url::Origin& p) {
: url::Origin::UnsafelyCreateOriginWithoutNormalization(
scheme, host, port, suborigin);
- // If a unique origin was created, but the unique flag wasn't set, then
+ // If an opaque origin was created, but the opaque flag wasn't set, then
// the values provided to 'UnsafelyCreateOriginWithoutNormalization' were
// invalid; kill the renderer.

Powered by Google App Engine
This is Rietveld 408576698